<?php
//* Start the engine
include_once( get_template_directory() . '/lib/init.php' );

//* Child theme (do not remove)
define( 'CHILD_THEME_NAME', 'Spoonflower Blog' );
define( 'CHILD_THEME_URL', 'http://blog.spoonflower.com/' );
define( 'CHILD_THEME_VERSION', '2.2.2' );

//* Child Theme includes
require_once( get_stylesheet_directory() . '/includes/cpt-jobs.php' );
require_once( get_stylesheet_directory() . '/includes/sp-markup.php' );

//* Enqueue Google Fonts
add_action( 'wp_enqueue_scripts', 'spoonflower_google_fonts' );
function spoonflower_google_fonts() {

	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Lato:300,400,700,300italic,400italic,700italic', array(), CHILD_THEME_VERSION );

}

//* Add HTML5 markup structure
add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

//* Add Accessibility support
add_theme_support( 'genesis-accessibility', array( 'headings', 'drop-down-menu',  'search-form', 'skip-links', 'rems' ) );

//* Add viewport meta tag for mobile browsers
add_theme_support( 'genesis-responsive-viewport' );

//* Add support for an end of post widget
add_theme_support( 'genesis-after-entry-widget-area' );
remove_action( 'genesis_after_entry', 'genesis_after_entry_widget_area' );

// * Remove unused sidebars and layouts
genesis_unregister_layout( 'sidebar-content' );
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );
unregister_sidebar( 'sidebar-alt' );
unregister_sidebar( 'header-right' );

//* Add prev/next post navigation
add_action( 'genesis_after_entry', 'sb_prev_next_post_nav' );

function sb_prev_next_post_nav() {

	if ( ! is_singular( 'post' ) )
		return;

	genesis_markup( array(
		'html5'   => '<div %s>',
		'xhtml'   => '<div class="navigation">',
		'context' => 'adjacent-entry-pagination',
	) );

	echo '<div class="pagination-previous alignleft">';
	previous_post_link();
	echo '</div>';

	genesis_after_entry_widget_area();

	echo '<div class="pagination-next alignright">';
	next_post_link();
	echo '</div>';

	echo '</div>';

}

//* Customize the entry meta in the entry header (requires HTML5 theme support)
add_filter( 'genesis_post_info', 'sb_post_info_filter' );
function sb_post_info_filter($post_info) {
	$post_info = '[post_date] [post_edit]';
	return $post_info;
}

//* Add editor stylesheet
add_action( 'admin_init', 'sb_add_editor_styles' );
function sb_add_editor_styles() {
	$font_url = str_replace( ',', '%2C', '//fonts.googleapis.com/css?family=Lato:300,400,700' );
    add_editor_style( [$font_url, 'editor-style.css'] );
}


//* Customize search form input box text
add_filter( 'genesis_search_text', 'sb_search_text' );
function sb_search_text( $text ) {
	return esc_attr( 'Search the blog...' );
}
//* Image Sizes
add_image_size( 'related', 250, 250, true );
add_image_size( 'footer-widget', 325, 100, true );
